import * as i0 from '@angular/core';
import { EventEmitter, Component, ViewChild, Input, Output, HostListener, NgModule } from '@angular/core';
import moment from 'moment';
import * as i1 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

class NgxAngurlarTimePickerLibComponent {
    constructor() {
        this.hide = true;
        this.inside = false;
        this.selectedHourIndex = 0;
        this.selectedMinuteIndex = 0;
        this.selectedSecondIndex = 0;
        this.selectedAmPm = 'AM';
        this.firstCells = [0, 1, 2, 3, 4];
        this.lastHourCells = [19, 20, 21, 22, 23];
        this.lastMinuteCells = [55, 56, 57, 58, 59];
        this.patch = false;
        this.top = '0px';
        this.left = '0px';
        this.enableSecond = false;
        this.format = '24hr';
        this.backgroundColorCell = '#00b6ff';
        this.backgroundColorCellHover = '#b0e8ff';
        this.show = false;
        this.width = 100;
        this.aMpMHoverStatus = {
            am: {
                hover: false,
            },
            pm: {
                hover: false,
            },
        };
        this.onTimeChange = new EventEmitter();
        this.hours = this.generateCells(24);
        this.minutes = this.generateCells(60);
        this.seconds = this.generateCells(60);
    }
    ngOnInit() {
        let format12hr = this.enableSecond ? 'hh:mm:ss A' : 'hh:mm A';
        let format24hr = this.enableSecond ? 'HH:mm:ss' : 'HH:mm';
        console.log(moment);
        if (this.control.value.split(' ').length > 1) {
            if (this.format !== '12hr') {
                this.control.patchValue(moment(this.control.value, [format12hr]).format(format24hr));
            }
            else {
                this.control.patchValue(moment(this.control.value, [format12hr]).format(format12hr));
            }
        }
        else {
            if (this.format === '12hr') {
                this.control.patchValue(moment(this.control.value, [format24hr]).format(format12hr));
            }
            else {
                this.control.patchValue(moment(this.control.value, [format24hr]).format(format24hr));
            }
        }
        if (this.format === '12hr') {
            this.hours = [
                ...this.generateCells(12).splice(1),
                { active: false, time: '12', hover: false },
            ];
            this.lastHourCells = [7, 8, 9, 10, 11];
            this.width += 50;
        }
        if (this.enableSecond) {
            this.width += 50;
        }
        if (this.control.value && this.control.value.split(':').length > 0) {
            this.selectedHourIndex =
                this.format === '12hr'
                    ? this.control.value.split(':')[0] - 1
                    : this.control.value.split(':')[0];
            this.selectedMinuteIndex = moment(this.control.value, [
                this.format === '12hr' ? format12hr : format24hr,
            ]).format('mm');
            if (this.enableSecond && this.control.value.split(':').length > 2) {
                this.selectedSecondIndex = moment(this.control.value, [
                    this.format === '12hr' ? format12hr : format24hr,
                ]).format('ss');
            }
            if (this.format === '12hr') {
                this.selectedAmPm = moment(this.control.value, [
                    this.format === '12hr' ? format12hr : format24hr,
                ])
                    .format('A')
                    .toUpperCase();
            }
            this.patch = true;
        }
        this.selectHour(parseInt(this.selectedHourIndex), this.patch);
        this.selectMinute(parseInt(this.selectedMinuteIndex), this.patch);
        if (this.enableSecond && this.control.value.split(':').length > 2) {
            this.selectSecond(parseInt(this.selectedSecondIndex), this.patch);
        }
        if (this.format === '12hr') {
            this.selectAmPm(this.selectedAmPm, this.patch);
        }
        this.show = true;
    }
    clicked() {
        this.inside = true;
    }
    clickedOut() {
        if (!this.inside) {
            this.hide = true;
        }
        this.inside = false;
    }
    onInputClick() {
        let tempHide = this.hide;
        this.hide = false;
        setTimeout(() => {
            if (tempHide != this.hide) {
                this.hourContainer.nativeElement.scrollTop =
                    this.selectedHourIndex * 50 + 250;
                this.minuteContainer.nativeElement.scrollTop =
                    this.selectedMinuteIndex * 50 + 250;
                if (this.enableSecond) {
                    this.secondContainer.nativeElement.scrollTop =
                        this.selectedSecondIndex * 50 + 250;
                }
            }
        }, 100);
    }
    generateCells(length) {
        //@ts-ignore
        return Array.apply(null, { length })
            .map(Number.call, Number)
            .map((item, index) => {
            let cell = { active: false };
            //@ts-ignore
            if (item < 10)
                return { ...cell, time: `0${item}` };
            return { ...cell, time: `${item}`, hover: false };
        });
    }
    selectHour(i, patch = true) {
        let format12hr = this.enableSecond ? 'hh:mm:ss A' : 'hh:mm A';
        let format24hr = this.enableSecond ? 'HH:mm:ss' : 'HH:mm';
        if (patch) {
            this.selectedHourIndex = i;
            this.hours = this.hours.map((hour, index) => {
                hour.active = index === i;
                let minute = '00';
                if (this.control.value && this.control.value.split(':').length > 0) {
                    minute = moment(this.control.value, [
                        this.format === '12hr' ? format12hr : format24hr,
                    ]).format('mm');
                }
                let time = `${hour.time}:${minute}`;
                if (this.enableSecond) {
                    let second = '00';
                    if (this.control.value && this.control.value.split(':').length > 2) {
                        second = `${this.format === '12hr'
                            ? this.control.value.split(':')[2].split(' ')[0]
                            : this.control.value.split(':')[2]}`;
                    }
                    time += `:${second}`;
                }
                if (index === i) {
                    if (this.format === '12hr') {
                        time += ` ${this.selectedAmPm}`;
                    }
                    this.outputTime(`${time}`);
                }
                return hour;
            });
        }
    }
    selectMinute(i, patch = true) {
        if (patch) {
            this.selectedMinuteIndex = i;
            this.minutes = this.minutes.map((minute, index) => {
                minute.active = index === i;
                let hour = '00';
                if (this.control.value && this.control.value.split(':').length > 0) {
                    hour = `${this.control.value.split(':')[0]}`;
                }
                let time = `${hour}:${minute.time}`;
                if (this.enableSecond) {
                    let second = '00';
                    if (this.control.value && this.control.value.split(':').length > 2) {
                        second = `${this.format === '12hr'
                            ? this.control.value.split(':')[2].split(' ')[0]
                            : this.control.value.split(':')[2]}`;
                    }
                    time += `:${second}`;
                }
                if (index === i) {
                    if (this.format === '12hr') {
                        time += ` ${this.selectedAmPm}`;
                    }
                    this.outputTime(`${time}`);
                }
                return minute;
            });
        }
    }
    selectSecond(i, patch = true) {
        if (patch) {
            this.selectedSecondIndex = i;
            this.seconds = this.seconds.map((second, index) => {
                second.active = index === i;
                let hour = '00';
                if (this.control.value && this.control.value.split(':').length > 0) {
                    hour = `${this.control.value.split(':')[0]}`;
                }
                let minute = '00';
                if (this.control.value && this.control.value.split(':').length > 0) {
                    minute = `${this.control.value.split(':')[1]}`;
                }
                let time = `${hour}:${minute}`;
                if (index === i) {
                    time += `:${second.time}`;
                    if (this.format === '12hr') {
                        time += ` ${this.selectedAmPm}`;
                    }
                    this.outputTime(`${time}`);
                }
                return second;
            });
        }
    }
    selectAmPm(aMpM, patch = true) {
        let format12hr = this.enableSecond ? 'hh:mm:ss A' : 'hh:mm A';
        let format24hr = this.enableSecond ? 'HH:mm:ss' : 'HH:mm';
        if (patch) {
            this.selectedAmPm = aMpM;
            let hour = '00';
            if (this.control.value && this.control.value.split(':').length > 0) {
                hour = moment(this.control.value, [
                    this.format === '12hr' ? format12hr : format24hr,
                ]).format(this.format === '12hr' ? 'hh' : 'HH');
            }
            let minute = '00';
            if (this.control.value && this.control.value.split(':').length > 0) {
                minute = moment(this.control.value, [
                    this.format === '12hr' ? format12hr : format24hr,
                ]).format('mm');
            }
            let time = `${hour}:${minute}`;
            if (this.enableSecond) {
                let second = '00';
                if (this.control.value && this.control.value.split(':').length > 2) {
                    second = `${this.format === '12hr'
                        ? this.control.value.split(':')[2].split(' ')[0]
                        : this.control.value.split(':')[2]}`;
                }
                time += `:${second}`;
            }
            this.outputTime(`${time} ${this.selectedAmPm}`);
        }
    }
    activeAmPm(aMpM) {
        return this.selectedAmPm == aMpM;
    }
    //@ts-ignore
    onScrollLoopCheck(e, section) {
        if (e.target.offsetHeight + e.target.scrollTop >= e.target.scrollHeight) {
            if (section == 'hour')
                this.hourContainer.nativeElement.scrollTop = 251;
            if (section == 'minute')
                this.minuteContainer.nativeElement.scrollTop = 251;
            if (section == 'second')
                this.secondContainer.nativeElement.scrollTop = 251;
        }
        if (e.target.scrollTop == 0) {
            if (section == 'hour')
                this.hourContainer.nativeElement.scrollTop =
                    e.target.scrollHeight - 501;
            if (section == 'minute')
                this.minuteContainer.nativeElement.scrollTop =
                    e.target.scrollHeight - 501;
            if (section == 'second')
                this.secondContainer.nativeElement.scrollTop =
                    e.target.scrollHeight - 501;
        }
    }
    arrowTicker(delta, section) {
        if (section === 'hour') {
            this.hourContainer.nativeElement.scrollTop =
                this.hourContainer.nativeElement.scrollTop + delta;
        }
        else if (section === 'minute') {
            this.minuteContainer.nativeElement.scrollTop =
                this.minuteContainer.nativeElement.scrollTop + delta;
        }
        else if (section === 'second') {
            this.secondContainer.nativeElement.scrollTop =
                this.secondContainer.nativeElement.scrollTop + delta;
        }
    }
    outputTime(time) {
        this.control.patchValue(time);
        let output = {};
        let format12hr = this.enableSecond ? 'hh:mm:ss A' : 'hh:mm A';
        let format24hr = this.enableSecond ? 'HH:mm:ss' : 'HH:mm';
        if (this.format === '12hr') {
            output = {
                ...output,
                '12hr': time,
                '24hr': moment(time, [format12hr]).format(format24hr),
            };
        }
        else {
            output = {
                ...output,
                '12hr': moment(time, [format24hr]).format(format12hr),
                '24hr': time,
            };
        }
        this.onTimeChange.emit(output);
    }
}
NgxAngurlarTimePickerLibComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.3", ngImport: i0, type: NgxAngurlarTimePickerLibComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxAngurlarTimePickerLibComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.3", type: NgxAngurlarTimePickerLibComponent, selector: "ngx-angular-time-picker", inputs: { control: "control", top: "top", left: "left", enableSecond: "enableSecond", format: "format", backgroundColorCell: "backgroundColorCell", backgroundColorCellHover: "backgroundColorCellHover" }, outputs: { onTimeChange: "onTimeChange" }, host: { listeners: { "click": "clicked()", "document:click": "clickedOut()" } }, viewQueries: [{ propertyName: "hourContainer", first: true, predicate: ["hourContainer"], descendants: true }, { propertyName: "minuteContainer", first: true, predicate: ["minuteContainer"], descendants: true }, { propertyName: "secondContainer", first: true, predicate: ["secondContainer"], descendants: true }], ngImport: i0, template: "<div (click)=\"onInputClick()\" class=\"time-picker-wrapper\">\n  <ng-content></ng-content>\n  <div\n    class=\"time-selector-box\"\n    [class.time-selector-box-open]=\"!hide\"\n    [style.top]=\"top\"\n    [style.left]=\"left\"\n    [style.width]=\"width + 'px'\"\n    *ngIf=\"show\"\n  >\n    <div class=\"up-arrow\" (click)=\"arrowTicker(-50, 'hour')\">\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_up icon\"\n        >keyboard_arrow_up</mat-icon\n      >\n    </div>\n    <div\n      class=\"selector-column\"\n      (scroll)=\"onScrollLoopCheck($event, 'hour')\"\n      #hourContainer\n    >\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let lastHourCell of lastHourCells\"\n        [class.active]=\"hours[lastHourCell].active\"\n        (click)=\"selectHour(lastHourCell)\"\n        (mouseover)=\"hours[lastHourCell].hover = true\"\n        (mouseleave)=\"hours[lastHourCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': hours[lastHourCell].active\n            ? backgroundColorCell\n            : hours[lastHourCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        <ng-container *ngIf=\"format === '12hr'\">\n          {{ lastHourCell + 1 }}\n        </ng-container>\n        <ng-container *ngIf=\"format != '12hr'\">\n          {{ lastHourCell }}\n        </ng-container>\n      </div>\n      <div\n        *ngFor=\"let item of hours; let i = index\"\n        class=\"selector-cell\"\n        [class.active]=\"item.active\"\n        (click)=\"selectHour(i)\"\n        (mouseover)=\"item.hover = true\"\n        (mouseleave)=\"item.hover = false\"\n        [ngStyle]=\"{\n          'background-color': item.active\n            ? backgroundColorCell\n            : item.hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ item.time }}\n      </div>\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let firstCell of firstCells\"\n        [class.active]=\"hours[firstCell].active\"\n        (click)=\"selectHour(firstCell)\"\n        (mouseover)=\"hours[firstCell].hover = true\"\n        (mouseleave)=\"hours[firstCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': hours[firstCell].active\n            ? backgroundColorCell\n            : hours[firstCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        <ng-container *ngIf=\"format === '12hr'\">\n          0{{ firstCell + 1 }}\n        </ng-container>\n        <ng-container *ngIf=\"format != '12hr'\"> 0{{ firstCell }} </ng-container>\n      </div>\n    </div>\n    <div class=\"down-arrow\" (click)=\"arrowTicker(50, 'hour')\">\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_down icon\"\n        >keyboard_arrow_down</mat-icon\n      >\n    </div>\n    <div class=\"up-arrow up-arrow-minute\" (click)=\"arrowTicker(-50, 'minute')\">\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_up icon\"\n        >keyboard_arrow_up</mat-icon\n      >\n    </div>\n    <div\n      class=\"selector-column\"\n      (scroll)=\"onScrollLoopCheck($event, 'minute')\"\n      #minuteContainer\n    >\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let lastMinuteCell of lastMinuteCells\"\n        [class.active]=\"minutes[lastMinuteCell].active\"\n        (click)=\"selectMinute(lastMinuteCell)\"\n        (mouseover)=\"minutes[lastMinuteCell].hover = true\"\n        (mouseleave)=\"minutes[lastMinuteCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': minutes[lastMinuteCell].active\n            ? backgroundColorCell\n            : minutes[lastMinuteCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ lastMinuteCell }}\n      </div>\n      <div\n        *ngFor=\"let item of minutes; let i = index\"\n        class=\"selector-cell\"\n        [class.active]=\"item.active\"\n        (click)=\"selectMinute(i)\"\n        (mouseover)=\"item.hover = true\"\n        (mouseleave)=\"item.hover = false\"\n        [ngStyle]=\"{\n          'background-color': item.active\n            ? backgroundColorCell\n            : item.hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ item.time }}\n      </div>\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let firstCell of firstCells\"\n        [class.active]=\"minutes[firstCell].active\"\n        (click)=\"selectMinute(firstCell)\"\n        (mouseover)=\"minutes[firstCell].hover = true\"\n        (mouseleave)=\"minutes[firstCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': minutes[firstCell].active\n            ? backgroundColorCell\n            : minutes[firstCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        0{{ firstCell }}\n      </div>\n    </div>\n    <div\n      class=\"down-arrow down-arrow-minute\"\n      (click)=\"arrowTicker(50, 'minute')\"\n    >\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_down icon\"\n        >keyboard_arrow_down</mat-icon\n      >\n    </div>\n    <div\n      class=\"up-arrow up-arrow-second\"\n      (click)=\"arrowTicker(-50, 'second')\"\n      *ngIf=\"enableSecond\"\n    >\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_up icon\"\n        >keyboard_arrow_up</mat-icon\n      >\n    </div>\n    <div\n      class=\"selector-column\"\n      (scroll)=\"onScrollLoopCheck($event, 'second')\"\n      #secondContainer\n      *ngIf=\"enableSecond\"\n    >\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let lastMinuteCell of lastMinuteCells\"\n        [class.active]=\"seconds[lastMinuteCell].active\"\n        (click)=\"selectSecond(lastMinuteCell)\"\n        (mouseover)=\"seconds[lastMinuteCell].hover = true\"\n        (mouseleave)=\"seconds[lastMinuteCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': seconds[lastMinuteCell].active\n            ? backgroundColorCell\n            : seconds[lastMinuteCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ lastMinuteCell }}\n      </div>\n      <div\n        *ngFor=\"let item of seconds; let i = index\"\n        class=\"selector-cell\"\n        [class.active]=\"item.active\"\n        (click)=\"selectSecond(i)\"\n        (mouseover)=\"item.hover = true\"\n        (mouseleave)=\"item.hover = false\"\n        [ngStyle]=\"{\n          'background-color': item.active\n            ? backgroundColorCell\n            : item.hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ item.time }}\n      </div>\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let firstCell of firstCells\"\n        [class.active]=\"seconds[firstCell].active\"\n        (click)=\"selectSecond(firstCell)\"\n        (mouseover)=\"seconds[firstCell].hover = true\"\n        (mouseleave)=\"seconds[firstCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': seconds[firstCell].active\n            ? backgroundColorCell\n            : seconds[firstCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        0{{ firstCell }}\n      </div>\n    </div>\n    <div\n      class=\"down-arrow down-arrow-second\"\n      (click)=\"arrowTicker(50, 'second')\"\n      *ngIf=\"enableSecond\"\n    >\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_down icon\"\n        >keyboard_arrow_down</mat-icon\n      >\n    </div>\n    <div class=\"selector-column\" *ngIf=\"format === '12hr'\">\n      <div\n        class=\"selector-cell\"\n        [class.active]=\"activeAmPm('AM')\"\n        (click)=\"selectAmPm('AM')\"\n        (mouseover)=\"aMpMHoverStatus.am.hover = true\"\n        (mouseleave)=\"aMpMHoverStatus.am.hover = false\"\n        [ngStyle]=\"{\n          'background-color':\n            selectedAmPm == 'AM'\n              ? backgroundColorCell\n              : aMpMHoverStatus.am.hover\n              ? backgroundColorCellHover\n              : ''\n        }\"\n      >\n        AM\n      </div>\n      <div\n        class=\"selector-cell\"\n        [class.active]=\"activeAmPm('PM')\"\n        (click)=\"selectAmPm('PM')\"\n        (mouseover)=\"aMpMHoverStatus.pm.hover = true\"\n        (mouseleave)=\"aMpMHoverStatus.pm.hover = false\"\n        [ngStyle]=\"{\n          'background-color':\n            selectedAmPm == 'PM'\n              ? backgroundColorCell\n              : aMpMHoverStatus.pm.hover\n              ? backgroundColorCellHover\n              : ''\n        }\"\n      >\n        PM\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@import\"https://fonts.googleapis.com/icon?family=Material+Icons\";.time-picker-wrapper{position:relative;box-sizing:border-box}.icon-wrapper{position:absolute;right:10px;top:-6px;color:#757575;cursor:pointer;box-sizing:border-box}.time-selector-box{position:absolute;height:0px;transition:all .3s ease;min-width:100px;background:#ffffff;z-index:99999;left:-11px;top:30px;overflow:hidden;box-sizing:border-box}.time-selector-box .selector-column{float:left;position:relative;width:50px;height:100%;-ms-overflow-style:none;scrollbar-width:none;overflow:auto;box-sizing:border-box}.time-selector-box .selector-column .selector-cell{padding:12px;font-size:18px;height:50px;cursor:pointer;border:2px solid #ffffff;box-sizing:border-box}.time-selector-box .selector-column .active{color:#fff}.time-selector-box .selector-column::-webkit-scrollbar{display:none}.time-selector-box .up-arrow{position:absolute;z-index:9;height:25px;width:50px;padding-left:12px;background:white;background:linear-gradient(180deg,white 0%,rgba(255,255,255,0) 100%);cursor:pointer;-webkit-user-select:none;user-select:none;box-sizing:border-box}.time-selector-box .up-arrow:hover{background:#d7d7d7;background:linear-gradient(180deg,#d7d7d7 0%,rgba(255,255,255,0) 100%)}.time-selector-box .up-arrow-minute{left:50px!important}.time-selector-box .up-arrow-second{left:100px!important}.time-selector-box .down-arrow{position:absolute;z-index:9;height:25px;width:50px;padding-left:12px;background:white;background:linear-gradient(0deg,white 0%,rgba(255,255,255,0) 100%);cursor:pointer;bottom:0;-webkit-user-select:none;user-select:none;box-sizing:border-box}.time-selector-box .down-arrow:hover{background:#d7d7d7;background:linear-gradient(0deg,#d7d7d7 0%,rgba(255,255,255,0) 100%)}.time-selector-box .down-arrow-minute{left:50px!important}.time-selector-box .down-arrow-second{left:100px!important}.time-selector-box-open{height:250px;transition:all .3s ease;box-shadow:#00000029 0 10px 36px,#0000000f 0 0 0 1px;box-sizing:border-box}\n"], components: [{ type: i1.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.3", ngImport: i0, type: NgxAngurlarTimePickerLibComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-angular-time-picker', template: "<div (click)=\"onInputClick()\" class=\"time-picker-wrapper\">\n  <ng-content></ng-content>\n  <div\n    class=\"time-selector-box\"\n    [class.time-selector-box-open]=\"!hide\"\n    [style.top]=\"top\"\n    [style.left]=\"left\"\n    [style.width]=\"width + 'px'\"\n    *ngIf=\"show\"\n  >\n    <div class=\"up-arrow\" (click)=\"arrowTicker(-50, 'hour')\">\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_up icon\"\n        >keyboard_arrow_up</mat-icon\n      >\n    </div>\n    <div\n      class=\"selector-column\"\n      (scroll)=\"onScrollLoopCheck($event, 'hour')\"\n      #hourContainer\n    >\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let lastHourCell of lastHourCells\"\n        [class.active]=\"hours[lastHourCell].active\"\n        (click)=\"selectHour(lastHourCell)\"\n        (mouseover)=\"hours[lastHourCell].hover = true\"\n        (mouseleave)=\"hours[lastHourCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': hours[lastHourCell].active\n            ? backgroundColorCell\n            : hours[lastHourCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        <ng-container *ngIf=\"format === '12hr'\">\n          {{ lastHourCell + 1 }}\n        </ng-container>\n        <ng-container *ngIf=\"format != '12hr'\">\n          {{ lastHourCell }}\n        </ng-container>\n      </div>\n      <div\n        *ngFor=\"let item of hours; let i = index\"\n        class=\"selector-cell\"\n        [class.active]=\"item.active\"\n        (click)=\"selectHour(i)\"\n        (mouseover)=\"item.hover = true\"\n        (mouseleave)=\"item.hover = false\"\n        [ngStyle]=\"{\n          'background-color': item.active\n            ? backgroundColorCell\n            : item.hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ item.time }}\n      </div>\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let firstCell of firstCells\"\n        [class.active]=\"hours[firstCell].active\"\n        (click)=\"selectHour(firstCell)\"\n        (mouseover)=\"hours[firstCell].hover = true\"\n        (mouseleave)=\"hours[firstCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': hours[firstCell].active\n            ? backgroundColorCell\n            : hours[firstCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        <ng-container *ngIf=\"format === '12hr'\">\n          0{{ firstCell + 1 }}\n        </ng-container>\n        <ng-container *ngIf=\"format != '12hr'\"> 0{{ firstCell }} </ng-container>\n      </div>\n    </div>\n    <div class=\"down-arrow\" (click)=\"arrowTicker(50, 'hour')\">\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_down icon\"\n        >keyboard_arrow_down</mat-icon\n      >\n    </div>\n    <div class=\"up-arrow up-arrow-minute\" (click)=\"arrowTicker(-50, 'minute')\">\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_up icon\"\n        >keyboard_arrow_up</mat-icon\n      >\n    </div>\n    <div\n      class=\"selector-column\"\n      (scroll)=\"onScrollLoopCheck($event, 'minute')\"\n      #minuteContainer\n    >\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let lastMinuteCell of lastMinuteCells\"\n        [class.active]=\"minutes[lastMinuteCell].active\"\n        (click)=\"selectMinute(lastMinuteCell)\"\n        (mouseover)=\"minutes[lastMinuteCell].hover = true\"\n        (mouseleave)=\"minutes[lastMinuteCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': minutes[lastMinuteCell].active\n            ? backgroundColorCell\n            : minutes[lastMinuteCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ lastMinuteCell }}\n      </div>\n      <div\n        *ngFor=\"let item of minutes; let i = index\"\n        class=\"selector-cell\"\n        [class.active]=\"item.active\"\n        (click)=\"selectMinute(i)\"\n        (mouseover)=\"item.hover = true\"\n        (mouseleave)=\"item.hover = false\"\n        [ngStyle]=\"{\n          'background-color': item.active\n            ? backgroundColorCell\n            : item.hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ item.time }}\n      </div>\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let firstCell of firstCells\"\n        [class.active]=\"minutes[firstCell].active\"\n        (click)=\"selectMinute(firstCell)\"\n        (mouseover)=\"minutes[firstCell].hover = true\"\n        (mouseleave)=\"minutes[firstCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': minutes[firstCell].active\n            ? backgroundColorCell\n            : minutes[firstCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        0{{ firstCell }}\n      </div>\n    </div>\n    <div\n      class=\"down-arrow down-arrow-minute\"\n      (click)=\"arrowTicker(50, 'minute')\"\n    >\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_down icon\"\n        >keyboard_arrow_down</mat-icon\n      >\n    </div>\n    <div\n      class=\"up-arrow up-arrow-second\"\n      (click)=\"arrowTicker(-50, 'second')\"\n      *ngIf=\"enableSecond\"\n    >\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_up icon\"\n        >keyboard_arrow_up</mat-icon\n      >\n    </div>\n    <div\n      class=\"selector-column\"\n      (scroll)=\"onScrollLoopCheck($event, 'second')\"\n      #secondContainer\n      *ngIf=\"enableSecond\"\n    >\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let lastMinuteCell of lastMinuteCells\"\n        [class.active]=\"seconds[lastMinuteCell].active\"\n        (click)=\"selectSecond(lastMinuteCell)\"\n        (mouseover)=\"seconds[lastMinuteCell].hover = true\"\n        (mouseleave)=\"seconds[lastMinuteCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': seconds[lastMinuteCell].active\n            ? backgroundColorCell\n            : seconds[lastMinuteCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ lastMinuteCell }}\n      </div>\n      <div\n        *ngFor=\"let item of seconds; let i = index\"\n        class=\"selector-cell\"\n        [class.active]=\"item.active\"\n        (click)=\"selectSecond(i)\"\n        (mouseover)=\"item.hover = true\"\n        (mouseleave)=\"item.hover = false\"\n        [ngStyle]=\"{\n          'background-color': item.active\n            ? backgroundColorCell\n            : item.hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        {{ item.time }}\n      </div>\n      <div\n        class=\"selector-cell\"\n        *ngFor=\"let firstCell of firstCells\"\n        [class.active]=\"seconds[firstCell].active\"\n        (click)=\"selectSecond(firstCell)\"\n        (mouseover)=\"seconds[firstCell].hover = true\"\n        (mouseleave)=\"seconds[firstCell].hover = false\"\n        [ngStyle]=\"{\n          'background-color': seconds[firstCell].active\n            ? backgroundColorCell\n            : seconds[firstCell].hover\n            ? backgroundColorCellHover\n            : ''\n        }\"\n      >\n        0{{ firstCell }}\n      </div>\n    </div>\n    <div\n      class=\"down-arrow down-arrow-second\"\n      (click)=\"arrowTicker(50, 'second')\"\n      *ngIf=\"enableSecond\"\n    >\n      <mat-icon aria-hidden=\"false\" aria-label=\"keyboard_arrow_down icon\"\n        >keyboard_arrow_down</mat-icon\n      >\n    </div>\n    <div class=\"selector-column\" *ngIf=\"format === '12hr'\">\n      <div\n        class=\"selector-cell\"\n        [class.active]=\"activeAmPm('AM')\"\n        (click)=\"selectAmPm('AM')\"\n        (mouseover)=\"aMpMHoverStatus.am.hover = true\"\n        (mouseleave)=\"aMpMHoverStatus.am.hover = false\"\n        [ngStyle]=\"{\n          'background-color':\n            selectedAmPm == 'AM'\n              ? backgroundColorCell\n              : aMpMHoverStatus.am.hover\n              ? backgroundColorCellHover\n              : ''\n        }\"\n      >\n        AM\n      </div>\n      <div\n        class=\"selector-cell\"\n        [class.active]=\"activeAmPm('PM')\"\n        (click)=\"selectAmPm('PM')\"\n        (mouseover)=\"aMpMHoverStatus.pm.hover = true\"\n        (mouseleave)=\"aMpMHoverStatus.pm.hover = false\"\n        [ngStyle]=\"{\n          'background-color':\n            selectedAmPm == 'PM'\n              ? backgroundColorCell\n              : aMpMHoverStatus.pm.hover\n              ? backgroundColorCellHover\n              : ''\n        }\"\n      >\n        PM\n      </div>\n    </div>\n  </div>\n</div>\n", styles: ["@import\"https://fonts.googleapis.com/icon?family=Material+Icons\";.time-picker-wrapper{position:relative;box-sizing:border-box}.icon-wrapper{position:absolute;right:10px;top:-6px;color:#757575;cursor:pointer;box-sizing:border-box}.time-selector-box{position:absolute;height:0px;transition:all .3s ease;min-width:100px;background:#ffffff;z-index:99999;left:-11px;top:30px;overflow:hidden;box-sizing:border-box}.time-selector-box .selector-column{float:left;position:relative;width:50px;height:100%;-ms-overflow-style:none;scrollbar-width:none;overflow:auto;box-sizing:border-box}.time-selector-box .selector-column .selector-cell{padding:12px;font-size:18px;height:50px;cursor:pointer;border:2px solid #ffffff;box-sizing:border-box}.time-selector-box .selector-column .active{color:#fff}.time-selector-box .selector-column::-webkit-scrollbar{display:none}.time-selector-box .up-arrow{position:absolute;z-index:9;height:25px;width:50px;padding-left:12px;background:white;background:linear-gradient(180deg,white 0%,rgba(255,255,255,0) 100%);cursor:pointer;-webkit-user-select:none;user-select:none;box-sizing:border-box}.time-selector-box .up-arrow:hover{background:#d7d7d7;background:linear-gradient(180deg,#d7d7d7 0%,rgba(255,255,255,0) 100%)}.time-selector-box .up-arrow-minute{left:50px!important}.time-selector-box .up-arrow-second{left:100px!important}.time-selector-box .down-arrow{position:absolute;z-index:9;height:25px;width:50px;padding-left:12px;background:white;background:linear-gradient(0deg,white 0%,rgba(255,255,255,0) 100%);cursor:pointer;bottom:0;-webkit-user-select:none;user-select:none;box-sizing:border-box}.time-selector-box .down-arrow:hover{background:#d7d7d7;background:linear-gradient(0deg,#d7d7d7 0%,rgba(255,255,255,0) 100%)}.time-selector-box .down-arrow-minute{left:50px!important}.time-selector-box .down-arrow-second{left:100px!important}.time-selector-box-open{height:250px;transition:all .3s ease;box-shadow:#00000029 0 10px 36px,#0000000f 0 0 0 1px;box-sizing:border-box}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { hourContainer: [{
                type: ViewChild,
                args: ['hourContainer']
            }], minuteContainer: [{
                type: ViewChild,
                args: ['minuteContainer']
            }], secondContainer: [{
                type: ViewChild,
                args: ['secondContainer']
            }], control: [{
                type: Input,
                args: ['control']
            }], top: [{
                type: Input,
                args: ['top']
            }], left: [{
                type: Input,
                args: ['left']
            }], enableSecond: [{
                type: Input,
                args: ['enableSecond']
            }], format: [{
                type: Input,
                args: ['format']
            }], backgroundColorCell: [{
                type: Input,
                args: ['backgroundColorCell']
            }], backgroundColorCellHover: [{
                type: Input,
                args: ['backgroundColorCellHover']
            }], onTimeChange: [{
                type: Output
            }], clicked: [{
                type: HostListener,
                args: ['click']
            }], clickedOut: [{
                type: HostListener,
                args: ['document:click']
            }] } });

class NgxAngularTimePickerLibraryModule {
}
NgxAngularTimePickerLibraryModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.3", ngImport: i0, type: NgxAngularTimePickerLibraryModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxAngularTimePickerLibraryModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.3", ngImport: i0, type: NgxAngularTimePickerLibraryModule, declarations: [NgxAngurlarTimePickerLibComponent], imports: [CommonModule, MatIconModule], exports: [NgxAngurlarTimePickerLibComponent] });
NgxAngularTimePickerLibraryModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.3", ngImport: i0, type: NgxAngularTimePickerLibraryModule, imports: [[CommonModule, MatIconModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.3", ngImport: i0, type: NgxAngularTimePickerLibraryModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxAngurlarTimePickerLibComponent],
                    imports: [CommonModule, MatIconModule],
                    exports: [NgxAngurlarTimePickerLibComponent],
                }]
        }] });

/*
 * Public API Surface of ngx-angular-time-picker-library
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxAngularTimePickerLibraryModule, NgxAngurlarTimePickerLibComponent };
//# sourceMappingURL=ngx-angular-time-picker-library.mjs.map
